==> kado-4.2.1.tgz: package/doc/guide/Introduction.md <==
# Introduction

Kado has been a long running idea of ours to help propel the JavaScript
community forward. The first few versions of Kado were a lot of experimentation
on how to better abstract the functionality of JavaScript applications in order
to reduce development time. Now Kado is ready for the big stage and has all
the supporting code and documentation to prove it!

## History

During the prototype process several usable versions were released
This version accomplished the goal of less work for the developer, and more time
spent preparing application code. Next, we learned that we could take this step
even further by changing Kado from a packaged application into a collection
of libraries that could be used to build what Kado was using with no
dependencies.

Now, after 6 months of work and 500+ commits Kado 4 is ready to see feedback
from our wonderful community. We hope that Kado 4 will vastly improve the
performance of your applications. Also, we hope that Kado 4 will reduce the
amount of code you have to write. Most importantly, Kado 4 will significantly
reduce the amount of third party software your application will depend upon. Our
goal is that Node.JS + Kado is a combination that puts the developer in control
and provides enough tool depth as well as documentation depth to build applications with
few to no outside dependencies.

## Why Use Kado

This is impmortant due to the fact  maintenance of those outside packages are
vital to the continued success of your applications. Without quality
maintenance, packages are susceptible to incompatibilities with future versions
of Node.JS as well as SECURITY VULNERABILITIES that may go unhandled!
Furthermore, without being able to easily introspect which packages each named
dependency relies on, it becomes a struggle making sure your application is
compliant with the imposed licenses.

Kado relieves that pain by providing common functionality to meet the needs of
command line applications and web servers without the use of external
software. Prior to Kado even basic web servers relied on hundreds of external
dependencies just to say hello world. We also believe Kado is just easier and
more fun to work with. However, we will let you be the judge of that!

## The Future of Kado

Moving forward Kado aims to achieve two primary mission goals. The first
is to provide a stable environment for applications written on Kado by using
an LTS backed release schedule. Second, we aim to merge more common application
functionality written on ES6+ and matching Kado standards into our package.
It is key to note that the Kado team is backed by Esited hosting and Nullivex
software, companies with a long standing history in the technology world dating
back to 2003. Our commitment to quality software continues to grow as does our
love for making easy to use libraries for your enjoyment.

## Conclusion

We hope this gives you some background so that you can be rest assured your
efforts in Kado will not go in vein. Ready to get started? Head over to our
[Quick Start](QuickStart.md) guide and get going in a few minutes!

==> kado-4.3.1.tgz: package/doc/guide/Introduction.md <==
# Introduction

Kado has been a long running idea of ours to help propel the JavaScript
community forward. The first few versions of Kado were a lot of experimentation
on how to better abstract the functionality of JavaScript applications in order
to reduce development time. Now Kado is ready for the big stage and has all
the supporting code and documentation to prove it!

## History

During the prototype process several usable versions were released
This version accomplished the goal of less work for the developer, and more time
spent preparing application code. Next, we learned that we could take this step
even further by changing Kado from a packaged application into a collection
of libraries that could be used to build what Kado was using with no
dependencies.

Now, after 6 months of work and 500+ commits Kado 4 is ready to see feedback
from our wonderful community. We hope that Kado 4 will vastly improve the
performance of your applications. Also, we hope that Kado 4 will reduce the
amount of code you have to write. Most importantly, Kado 4 will significantly
reduce the amount of third party software your application will depend upon. Our
goal is that Node.js + Kado is a combination that puts the developer in control
and provides enough tool depth as well as documentation depth to build applications with
few to no outside dependencies.

## Why Use Kado

This is impmortant due to the fact  maintenance of those outside packages are
vital to the continued success of your applications. Without quality
maintenance, packages are susceptible to incompatibilities with future versions
of Node.js as well as SECURITY VULNERABILITIES that may go unhandled!
Furthermore, without being able to easily introspect which packages each named
dependency relies on, it becomes a struggle making sure your application is
compliant with the imposed licenses.

Kado relieves that pain by providing common functionality to meet the needs of
command line applications and web servers without the use of external
software. Prior to Kado even basic web servers relied on hundreds of external
dependencies just to say hello world. We also believe Kado is just easier and
more fun to work with. However, we will let you be the judge of that!

## The Future of Kado

Moving forward Kado aims to achieve two primary mission goals. The first
is to provide a stable environment for applications written on Kado by using
an LTS backed release schedule. Second, we aim to merge more common application
functionality written on ES6+ and matching Kado standards into our package.
It is key to note that the Kado team is backed by Esited hosting and Nullivex
software, companies with a long standing history in the technology world dating
back to 2003. Our commitment to quality software continues to grow as does our
love for making easy to use libraries for your enjoyment.

## Conclusion

We hope this gives you some background so that you can be rest assured your
efforts in Kado will not go in vein. Ready to get started? Head over to our
[Quick Start](QuickStart.md) guide and get going in a few minutes!
